@@ -1,4 +1,4 @@
-/* Copyright 2012--2017 The Tor Project
+/* Copyright 2012--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.descriptor.impl;
@@ -464,29 +464,28 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = db.buildDescriptor();
     assertEquals("saberrider2008", descriptor.getNickname());
     assertEquals("94.134.192.243", descriptor.getAddress());
-    assertEquals(9001, (int) descriptor.getOrPort());
-    assertEquals(0, (int) descriptor.getSocksPort());
-    assertEquals(0, (int) descriptor.getDirPort());
+    assertEquals(9001, descriptor.getOrPort());
+    assertEquals(0, descriptor.getSocksPort());
+    assertEquals(0, descriptor.getDirPort());
     assertEquals("Tor 0.2.2.35 (git-b04388f9e7546a9f) on Linux i686",
         descriptor.getPlatform());
-    assertEquals(new TreeSet<Long>(Arrays.asList(
-        new Long[] { 1L, 2L, 3L, 4L })), descriptor.getProtocols().get("Link"));
-    assertEquals(new TreeSet<Long>(Arrays.asList(
-        new Long[] { 1L })), descriptor.getProtocols().get("LinkAuth"));
+    assertEquals(new TreeSet<>(Arrays.asList(
+        1L, 2L, 3L, 4L)), descriptor.getProtocols().get("Link"));
+    assertEquals(new TreeSet<>(Arrays.asList(
+        1L)), descriptor.getProtocols().get("LinkAuth"));
     assertEquals(1325390599000L, descriptor.getPublishedMillis());
     assertEquals("D8733048FC8EC9102466AD8F3098622BF1BF71FD",
         descriptor.getFingerprint());
     assertEquals(48, descriptor.getUptime().longValue());
-    assertEquals(51200, (int) descriptor.getBandwidthRate());
-    assertEquals(51200, (int) descriptor.getBandwidthBurst());
-    assertEquals(53470, (int) descriptor.getBandwidthObserved());
+    assertEquals(51200, descriptor.getBandwidthRate());
+    assertEquals(51200, descriptor.getBandwidthBurst());
+    assertEquals(53470, descriptor.getBandwidthObserved());
     assertEquals("1469D1550738A25B1E7B47CDDBCD7B2899F51B74",
         descriptor.getExtraInfoDigestSha1Hex());
-    assertEquals(Arrays.asList(new Integer[] {2}),
-        descriptor.getHiddenServiceDirVersions());
+    assertTrue(descriptor.isHiddenServiceDir());
     assertEquals("Random Person <nobody AT example dot com>",
         descriptor.getContact());
-    assertEquals(Arrays.asList(new String[] {"reject *:*"}),
+    assertEquals(Arrays.asList("reject *:*"),
         descriptor.getExitPolicyLines());
     assertFalse(descriptor.isHibernating());
     assertNull(descriptor.getFamilyEntries());
@@ -517,9 +516,9 @@ public class ServerDescriptorImplTest {
         + "94.134.192.243 9001 0 0");
     assertEquals("saberrider2008", descriptor.getNickname());
     assertEquals("94.134.192.243", descriptor.getAddress());
-    assertEquals(9001, (int) descriptor.getOrPort());
-    assertEquals(0, (int) descriptor.getSocksPort());
-    assertEquals(0, (int) descriptor.getDirPort());
+    assertEquals(9001, descriptor.getOrPort());
+    assertEquals(0, descriptor.getSocksPort());
+    assertEquals(0, descriptor.getDirPort());
   }
 
   @Test
@@ -674,9 +673,9 @@ public class ServerDescriptorImplTest {
   public void testProtocolsOpt() throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithProtocolsLine("opt protocols Link 1 2 Circuit 1");
-    assertEquals(Arrays.asList(new Integer[] {1, 2}),
+    assertEquals(Arrays.asList(1, 2),
         descriptor.getLinkProtocolVersions());
-    assertEquals(Arrays.asList(new Integer[] {1}),
+    assertEquals(Arrays.asList(1),
         descriptor.getCircuitProtocolVersions());
   }
 
@@ -684,9 +683,9 @@ public class ServerDescriptorImplTest {
   public void testProtocolsNoOpt() throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithProtocolsLine("protocols Link 1 2 Circuit 1");
-    assertEquals(Arrays.asList(new Integer[] {1, 2}),
+    assertEquals(Arrays.asList(1, 2),
         descriptor.getLinkProtocolVersions());
-    assertEquals(Arrays.asList(new Integer[] {1}),
+    assertEquals(Arrays.asList(1),
         descriptor.getCircuitProtocolVersions());
   }
 
@@ -711,9 +710,9 @@ public class ServerDescriptorImplTest {
   public void testProtoGreenPurple() throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithProtoLine("proto Green=23 Purple=42");
-    assertEquals(new TreeSet<Long>(Arrays.asList(new Long[] { 23L })),
+    assertEquals(new TreeSet<>(Arrays.asList(23L)),
         descriptor.getProtocols().get("Green"));
-    assertEquals(new TreeSet<Long>(Arrays.asList(new Long[] { 42L })),
+    assertEquals(new TreeSet<>(Arrays.asList(42L)),
         descriptor.getProtocols().get("Purple"));
   }
 
@@ -877,9 +876,9 @@ public class ServerDescriptorImplTest {
   public void testBandwidthOpt() throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithBandwidthLine("opt bandwidth 51200 51200 53470");
-    assertEquals(51200, (int) descriptor.getBandwidthRate());
-    assertEquals(51200, (int) descriptor.getBandwidthBurst());
-    assertEquals(53470, (int) descriptor.getBandwidthObserved());
+    assertEquals(51200, descriptor.getBandwidthRate());
+    assertEquals(51200, descriptor.getBandwidthBurst());
+    assertEquals(53470, descriptor.getBandwidthObserved());
   }
 
   @Test
@@ -905,9 +904,9 @@ public class ServerDescriptorImplTest {
      * value. */
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithBandwidthLine("bandwidth 51200 51200");
-    assertEquals(51200, (int) descriptor.getBandwidthRate());
-    assertEquals(51200, (int) descriptor.getBandwidthBurst());
-    assertEquals(-1, (int) descriptor.getBandwidthObserved());
+    assertEquals(51200, descriptor.getBandwidthRate());
+    assertEquals(51200, descriptor.getBandwidthBurst());
+    assertEquals(-1, descriptor.getBandwidthObserved());
   }
 
   @Test
@@ -1014,7 +1013,7 @@ public class ServerDescriptorImplTest {
       throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithHiddenServiceDirLine(null);
-    assertNull(descriptor.getHiddenServiceDirVersions());
+    assertFalse(descriptor.isHiddenServiceDir());
   }
 
   @Test
@@ -1022,8 +1021,7 @@ public class ServerDescriptorImplTest {
       throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithHiddenServiceDirLine("hidden-service-dir");
-    assertEquals(Arrays.asList(new Integer[] {2}),
-        descriptor.getHiddenServiceDirVersions());
+    assertTrue(descriptor.isHiddenServiceDir());
   }
 
   @Test
@@ -1031,8 +1029,7 @@ public class ServerDescriptorImplTest {
       throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithHiddenServiceDirLine("hidden-service-dir 2 3");
-    assertEquals(Arrays.asList(new Integer[] {2, 3}),
-        descriptor.getHiddenServiceDirVersions());
+    assertTrue(descriptor.isHiddenServiceDir());
   }
 
   @Test
@@ -1085,7 +1082,7 @@ public class ServerDescriptorImplTest {
       throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithExitPolicyLines("reject *:*\naccept *:*");
-    assertEquals(Arrays.asList(new String[] {"reject *:*", "accept *:*"}),
+    assertEquals(Arrays.asList("reject *:*", "accept *:*"),
         descriptor.getExitPolicyLines());
   }
 
@@ -1093,7 +1090,7 @@ public class ServerDescriptorImplTest {
   public void testExitPolicyOpt() throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithExitPolicyLines("opt reject *:*");
-    assertEquals(Arrays.asList(new String[] {"reject *:*"}),
+    assertEquals(Arrays.asList("reject *:*"),
         descriptor.getExitPolicyLines());
   }
 
@@ -1110,8 +1107,8 @@ public class ServerDescriptorImplTest {
       throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithExitPolicyLines("accept *:80\nreject *:*");
-    assertEquals(Arrays.asList(new String[] {"accept *:80",
-        "reject *:*"}), descriptor.getExitPolicyLines());
+    assertEquals(Arrays.asList("accept *:80",
+        "reject *:*"), descriptor.getExitPolicyLines());
   }
 
   @Test
@@ -1153,8 +1150,8 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithExitPolicyLines("reject 192.168.0.0/16:*\n"
         + "reject 94.134.192.243/255.255.255.0:*");
-    assertEquals(Arrays.asList(new String[] { "reject 192.168.0.0/16:*",
-        "reject 94.134.192.243/255.255.255.0:*"}),
+    assertEquals(Arrays.asList("reject 192.168.0.0/16:*",
+        "reject 94.134.192.243/255.255.255.0:*"),
         descriptor.getExitPolicyLines());
   }
 
@@ -1221,7 +1218,7 @@ public class ServerDescriptorImplTest {
   public void testFamilyOpt() throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithFamilyLine("opt family saberrider2008");
-    assertEquals(Arrays.asList(new String[] {"saberrider2008"}),
+    assertEquals(Arrays.asList("saberrider2008"),
         descriptor.getFamilyEntries());
   }
 
@@ -1230,8 +1227,7 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithFamilyLine("family "
         + "$D8733048FC8EC9102466AD8F3098622BF1BF71FD");
-    assertEquals(Arrays.asList(new String[] {
-        "$D8733048FC8EC9102466AD8F3098622BF1BF71FD"}),
+    assertEquals(Arrays.asList("$D8733048FC8EC9102466AD8F3098622BF1BF71FD"),
         descriptor.getFamilyEntries());
   }
 
@@ -1239,7 +1235,7 @@ public class ServerDescriptorImplTest {
   public void testFamilyNickname() throws DescriptorParseException {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithFamilyLine("family saberrider2008");
-    assertEquals(Arrays.asList(new String[] {"saberrider2008"}),
+    assertEquals(Arrays.asList("saberrider2008"),
         descriptor.getFamilyEntries());
   }
 
@@ -1276,8 +1272,8 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithFamilyLine("family "
         + "$D8733048FC8EC9102466AD8F3098622BF1BF71FD=saberrider2008");
-    assertEquals(Arrays.asList(new String[]
-        { "$D8733048FC8EC9102466AD8F3098622BF1BF71FD=saberrider2008" }),
+    assertEquals(Arrays.asList(
+        "$D8733048FC8EC9102466AD8F3098622BF1BF71FD=saberrider2008"),
         descriptor.getFamilyEntries());
   }
 
@@ -1287,8 +1283,8 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithFamilyLine("family "
         + "$D8733048FC8EC9102466AD8F3098622BF1BF71FD~saberrider2008");
-    assertEquals(Arrays.asList(new String[]
-        { "$D8733048FC8EC9102466AD8F3098622BF1BF71FD~saberrider2008" }),
+    assertEquals(Arrays.asList(
+        "$D8733048FC8EC9102466AD8F3098622BF1BF71FD~saberrider2008"),
         descriptor.getFamilyEntries());
   }
 
@@ -1301,9 +1297,9 @@ public class ServerDescriptorImplTest {
     assertNotNull(descriptor.getWriteHistory());
     BandwidthHistory parsedWriteHistory = descriptor.getWriteHistory();
     assertEquals(writeHistoryLine, parsedWriteHistory.getLine());
-    assertEquals(1325389904000L, (long) parsedWriteHistory
+    assertEquals(1325389904000L, parsedWriteHistory
         .getHistoryEndMillis());
-    assertEquals(900L, (long) parsedWriteHistory.getIntervalLength());
+    assertEquals(900L, parsedWriteHistory.getIntervalLength());
     SortedMap<Long, Long> bandwidthValues = parsedWriteHistory
         .getBandwidthValues();
     assertEquals(4345856L, (long) bandwidthValues.remove(1325387204000L));
@@ -1389,7 +1385,7 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithWriteHistoryLine("write-history 2012-01-01 03:51:44 "
         + "(900 s) ");
-    assertEquals(900, (long) descriptor.getWriteHistory()
+    assertEquals(900, descriptor.getWriteHistory()
         .getIntervalLength());
     assertTrue(descriptor.getWriteHistory().getBandwidthValues()
         .isEmpty());
@@ -1401,7 +1397,7 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithWriteHistoryLine("write-history 2012-01-01 03:51:44 "
         + "(900 s)");
-    assertEquals(900, (long) descriptor.getWriteHistory()
+    assertEquals(900, descriptor.getWriteHistory()
         .getIntervalLength());
     assertTrue(descriptor.getWriteHistory().getBandwidthValues()
         .isEmpty());
@@ -1429,7 +1425,7 @@ public class ServerDescriptorImplTest {
     ServerDescriptor descriptor = DescriptorBuilder
         .createWithWriteHistoryLine("write-history 2012-01-01 03:51:44 "
         + "(1800 s) 4345856");
-    assertEquals(1800L, (long) descriptor.getWriteHistory()
+    assertEquals(1800L, descriptor.getWriteHistory()
         .getIntervalLength());
   }
 
@@ -1442,9 +1438,9 @@ public class ServerDescriptorImplTest {
     assertNotNull(descriptor.getReadHistory());
     BandwidthHistory parsedReadHistory = descriptor.getReadHistory();
     assertEquals(readHistoryLine, parsedReadHistory.getLine());
-    assertEquals(1325389904000L, (long) parsedReadHistory
+    assertEquals(1325389904000L, parsedReadHistory
         .getHistoryEndMillis());
-    assertEquals(900L, (long) parsedReadHistory.getIntervalLength());
+    assertEquals(900L, parsedReadHistory.getIntervalLength());
     SortedMap<Long, Long> bandwidthValues = parsedReadHistory
         .getBandwidthValues();
     assertEquals(4268032L, (long) bandwidthValues.remove(1325387204000L));
